carrot.backends.pystomp — Carrot v0.8.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.8.0 documentation »
- API Reference »

# carrot.backends.pystomp

class `carrot.backends.pystomp.` `Message`(backend, frame, **kwargs)

  A message received by the STOMP broker.

  Usually you don’t insantiate message objects yourself, but receive them using a `carrot.messaging.Consumer`.

  Parameters: | backend – see `backend`. frame – see `_frame`.

  `body`
    The message body.
  `delivery_tag`
    The message delivery tag, uniquely identifying this message.
  `backend`
    The message backend used. A subclass of `carrot.backends.base.BaseBackend`.
  `_frame`
    The frame received by the STOMP client. This is considered a private variable and should never be used in production code.
  `ack`()

    Acknowledge this message as being processed., This will remove the message from the queue.

    Raises MessageStateError:
    | If the message has already been acknowledged/requeued/rejected.

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.8.0 documentation »
- API Reference »